==> frezka_admin_panel_updated_files_v3.0.0.zip: lang/de/booking.php <==
<?php

return [
    'title' => 'Buchungen',
    'singular_title' => 'Buchung',
    'lbl_phone' => 'Telefon:',
    'lbl_e-mail' => 'E-Mail:',
    'lbl_with' => 'Mit',
    'lbl_at' => 'Am:',
    'lbl_note' => 'Hinweis',
    'lbl_sub_tot' => 'Zwischensumme:',
    'lbl_got_to_payment' => 'Zur Zahlung gehen',
    'lbl_complete_now' => 'Jetzt abschließen',
    'lbl_payment' => 'Zahlung',
    'lbl_pay_now' => 'Jetzt bezahlen',
    'lbl_is_paid' => 'Bezahlt',
    'lbl_add_service' => 'Service hinzufügen',
    'lbl_add_package' => 'Paket hinzufügen',
    'lbl_date' => 'Datum',
    'lbl_customer_name' => 'Kundenname',
    'lbl_amount' => 'Betrag',
    'lbl_duration' => 'Dauer',
    'lbl_staff_name' => 'Mitarbeitername',
    'lbl_services' => 'Dienstleistungen',
    'lbl_update_at' => 'Aktualisiert am',
    'lbl_status' => 'Status',
    'booking_update' => 'Buchung aktualisiert',
    'booking_status_list' => 'Buchungsstatusliste',
    'search_booking' => 'Suchergebnisse für Buchungen.',
    'booking_detail' => 'Buchungsdetail',
    'booking_list' => 'Buchungsliste',
    'status_update' => 'Status wurde aktualisiert!',
    'booking_delete' => 'Erfolgreich gelöscht',
    'booking_not_found' => 'Buchung nicht gefunden',
    'payment_done' => 'Zahlung erfolgreich',
    'booking_branch' => 'ZWEIGLISTE',
    'booking_timeslot' => 'ZEITSCHLITZ_LISTE',
    'booking_category' => 'KATEGORIE_LISTE',
    'booking_sevice' => 'DIENSTLISTE',
    'booking_employee' => 'MITARBEITERLISTE',
    'booking_create' => 'ERSTELLTE_BUCHUNG',
    'booking_action_invalid' => 'Ungültige Aktion',
    'booking_service_update' => 'Buchungsservice erfolgreich aktualisiert',
    'payment_successfull' => 'Zahlung erfolgreich abgeschlossen',
    'create_form' => ':form wurde erfolgreich erstellt',
    'lbl_action' => 'Aktion',
    'lbl_new_appointment' => 'Neuer Termin',
    'lbl_appointment' => 'Termin',
    'lbl_advanced_filter' => 'Erweiterter Filter',
    'lbl_booking_date' => 'Buchungsdatum',
    'lbl_customer_name' => 'Kundenname',
    'lbl_staff_name' => 'Mitarbeitername',
    'lbl_services' => 'Dienstleistungen',
    'lbl_payment_status' => 'Zahlungsstatus',
    'download_invoice' => 'Rechnung herunterladen',
    'name' => 'Name',
    'phone' => 'Telefon',
    'email' => 'E-Mail',
    'payment_method' => 'Zahlungsmethode',
    'customer_info' => 'Kundeninformationen',
    'services' => 'Dienstleistungen',
    'unit_price' => 'Stückpreis',
    'qty' => 'Menge',
    'total_price' => 'Gesamtpreis',
    'tips' => 'Tipps',
    'tax' => 'Steuer',
    'grand-total' => 'Gesamtsumme',
    'sub_total' => 'Zwischensumme',
    'products' => 'Produkte',
    'invoice_data' => 'Rechnungsdaten',
    'coupondiscount' => 'Gutscheinrabatt',
    'grand_total' => 'Gesamtsumme',
    'tips' => 'Trinkgeld',
    'billing_address' => 'Rechnungsadresse'
    
];

==> frezka_admin_panel_updated_files_v3.3.0.zip: lang/de/booking.php <==
<?php

return [
    'title' => 'Buchungen',
    'singular_title' => 'Buchung',
    'lbl_phone' => 'Telefon:',
    'lbl_e-mail' => 'E-Mail:',
    'lbl_with' => 'Mit',
    'lbl_at' => 'Am:',
    'lbl_note' => 'Hinweis',
    'lbl_sub_tot' => 'Zwischensumme:',
    'lbl_got_to_payment' => 'Zur Zahlung gehen',
    'lbl_complete_now' => 'Jetzt abschließen',
    'lbl_payment' => 'Zahlung',
    'lbl_pay_now' => 'Jetzt bezahlen',
    'lbl_is_paid' => 'Bezahlt',
    'lbl_add_service' => 'Service hinzufügen',
    'lbl_add_package' => 'Paket hinzufügen',
    'lbl_date' => 'Datum',
    'lbl_customer_name' => 'Kunde',
    'lbl_amount' => 'Betrag',
    'lbl_duration' => 'Dauer',
    'lbl_staff_name' => 'Mitarbeiter',
    'lbl_services' => 'Dienstleistungen',
    'lbl_update_at' => 'Aktualisiert am',
    'lbl_status' => 'Status',
    'booking_update' => 'Buchung aktualisiert',
    'booking_status_list' => 'Buchungsstatusliste',
    'search_booking' => 'Suchergebnisse für Buchungen.',
    'booking_detail' => 'Buchungsdetail',
    'booking_list' => 'Buchungsliste',
    'status_update' => 'Status wurde aktualisiert!',
    'booking_delete' => 'Erfolgreich gelöscht',
    'booking_not_found' => 'Buchung nicht gefunden',
    'payment_done' => 'Zahlung erfolgreich',
    'booking_branch' => 'ZWEIGLISTE',
    'booking_timeslot' => 'ZEITSCHLITZ_LISTE',
    'booking_category' => 'KATEGORIE_LISTE',
    'booking_sevice' => 'DIENSTLISTE',
    'booking_employee' => 'MITARBEITERLISTE',
    'booking_create' => 'ERSTELLTE_BUCHUNG',
    'booking_action_invalid' => 'Ungültige Aktion',
    'booking_service_update' => 'Buchungsservice erfolgreich aktualisiert',
    'payment_successfull' => 'Zahlung erfolgreich abgeschlossen',
    'create_form' => ':form wurde erfolgreich erstellt',
    'lbl_action' => 'Aktion',
    'lbl_new_appointment' => 'Neuer Termin',
    'lbl_appointment' => 'Termin',
    'lbl_advanced_filter' => 'Erweiterter Filter',
    'lbl_booking_date' => 'Buchungsdatum',
    'lbl_customer_name' => 'Kundenname',
    'lbl_staff_name' => 'Mitarbeitername',
    'lbl_services' => 'Dienstleistungen',
    'lbl_payment_status' => 'Zahlungsstatus',
    'download_invoice' => ' herunterladen',
    'name' => 'Name',
    'phone' => 'Telefon',
    'email' => 'E-Mail',
    'payment_method' => 'Zahlungsmethode',
    'customer_info' => 'Kundeninformationen',
    'services' => 'Dienstleistungen',
    'unit_price' => 'Stückpreis',
    'qty' => 'Menge',
    'total_price' => 'Gesamtpreis',
    'tips' => 'Tipps',
    'tax' => 'Steuer',
    'grand-total' => 'Gesamtsumme',
    'sub_total' => 'Zwischensumme',
    'products' => 'Produkte',
    'invoice_data' => 'Rechnungsdaten',
    'coupondiscount' => 'Gutscheinrabatt',
    'grand_total' => 'Gesamtsumme',
    'tips' => 'Trinkgeld',
    'billing_address' => 'Rechnungsadresse',
    'grand_total' => 'Gesamtsumme:',
    'lbl_packages' => 'Pakete',
    'lbl_add_more' => 'Mehr hinzufügen',
    'lbl_packages_detail' => 'Pakete Details',
    'lbl_package_available' => 'Verfügbare Pakete',
    'lbl_package_active' => 'Ihr Paket ist noch aktiv',
    'lbl_view_all' => 'Alle anzeigen',
    'booking_date' => 'Buchungsdatum auswählen',
    'customer_name' => 'Kundennamen auswählen',
    'staff_name' => 'Mitarbeiternamen auswählen',
    'select_service' => 'Dienstleistungen auswählen',
    'branch_name' => 'Filialname',
    'invoice_time' => 'Rechnungszeit',
    'payment_type' => 'Zahlungsart',
    'service_amount' => 'Dienstleistungsbetrag',
    'product_amount'=> 'Produktbetrag',
    'package_amount' => 'Paketbetrag',
    'tip_amount' => 'Trinkgeld',
    'total' => 'Gesamt',
    'final_total' => 'Endbetrag',
    'booking_detail' => 'Buchungsdetails',
    'booked_on' => 'Gebucht am',
    'booked_by' => 'Gebucht von',
    'updated_on' => 'Aktualisiert am',
    'updated_by' => 'Aktualisiert von',
    'sale' => 'Verkauf #0',
    'with' => 'Mit',
    'sold_by' => 'Verkauft von',
    'client_since' => 'Kunde seit',
    'coupon_discount' => 'Gutscheinrabatt',

];
